/**
 * Copyright 1&1 Internet AG, https://github.com/1and1/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.oneandone.graph;

import java.util.ArrayList;
import java.util.Iterator;


public class EdgeIterator<T> {
    /** points behind the current  to the next candidate */
    private final Iterator<Node<T>> lefts;
    private Iterator<Node<T>> rights;

    private T left;
    private T right;
    
    public EdgeIterator(Iterator<Node<T>> lefts) {
        this.lefts = lefts;
        this.rights = null;
    }
    
    public boolean step() {
        Node<T> tmp;
        
        if (rights != null && rights.hasNext()) {
            right = rights.next().data;
            return true;
        } 
        while (lefts.hasNext()) {
            tmp = lefts.next();
            if (tmp.starting.size() > 0) {
                left = tmp.data;
                // TODO
                rights = new ArrayList<Node<T>>(tmp.starting).iterator();
                right = rights.next().data;
                return true;
            }
        }
        return false;
    }

    /** undefined without previously calling step() */
    public T left() {
        return left;
    }

    /** undefined without previously calling step() */
    public T right() {
        return right;
    }
}
